import pulumi
import pulumi_docker as docker
import json
<<<<<<< HEAD

# Load the configuration from the JSON file
with open('config.json') as f:
    config_data = json.load(f)

# Create a Docker network
network = docker.Network("testNetwork")

# Initialize the containers list
containers = []


# Initialize the URL dictionary for export
urls = {}

# Create containers based on the configuration
for container in config_data["containers"]:
    container_name = container["name"]
    container_envs = [f"{key}={value}" for key, value in container.get("env", {}).items()]

    # Create the container
    docker_container = docker.Container(
        container_name,
        name=container_name,
        image=container["image"],
        envs=container_envs,
        ports=[docker.ContainerPortArgs(
            internal=port["internal"],
            external=port["external"]
        ) for port in container["ports"]],
        network_mode=network.name,
        command=container.get("command", None) or container.get("entrypoint", None),
        ##container.get("entrypoint", "/usr/local/bin/entrypoint.sh") 
        
        volumes=[docker.ContainerVolumeArgs(
            host_path=vol["host_path"],
            container_path=vol["container_path"]
        ) for vol in container.get("volumes", [])]
    )
    containers.append(docker_container)

    # Add the URLs for the container
    for port in container["ports"]:
        urls[f"{container_name}_url"] = f"http://localhost:{port['external']}"

# Scale Prometheus containers
for i in range(config_data.get("prometheus_scale", 1)):  # Default to 1 if not specified
    prometheus_instance = docker.Container(
        f"prometheus-instance-{i}",
        name=f"prometheus-{i}",
        image="prom/prometheus:latest",
        ports=[docker.ContainerPortArgs(internal=9090, external=9090 + i)],
        network_mode=network.name
    )
    containers.append(prometheus_instance)

    # Add the Prometheus URLs
    urls[f"prometheus_{i}_url"] = f"http://localhost:{9090 + i}"

# Scale Fluentd containers
fluentd_scale = config_data.get("fluentd_scale", 1)  # Default to 1 if not specified

for i in range(fluentd_scale):  # This will scale based on the value from config_data
    fluentd_instance = docker.Container(
        f"fluentd-instance-{i}",
        name=f"fluentd-{i}",
        image="fluent/fluentd:v1.14-1",  # Corrected image name
        ports=[docker.ContainerPortArgs(internal=24224, external=24224 + i)],  # Assign unique external port for each container
        network_mode=network.name
    )
    containers.append(fluentd_instance)

    # Add the Fluentd URLs
    urls[f"fluentd_{i}_url"] = f"http://localhost:{24224 + i}"

# Export network and container details
pulumi.export("network_name", network.name)
pulumi.export("containers", [c.name for c in containers])
pulumi.export("urls", urls)
=======
import os

# Load the JSON configuration file
try:
    with open("config.json", "r") as f:
        containers_data = json.load(f)
except FileNotFoundError:
    raise Exception("Error: 'config.json' file not found.")

# Create the network
try:
    network = docker.Network("testNetwork")
     
except Exception as e:
    pulumi.log.error(f"Failed to create network: {e}")
    network = None

# Create containers
for container in containers_data.get("containers", []):
    instances = container.get("instances", 1)
    for i in range(instances):
        container_name = f"{container['name']}-{i}" if instances > 1 else container["name"]
        
        # Configure volumes
        volumes = {}
        for volume in container.get("volumes", []):
            try:
                if "volume_name" in volume and volume["volume_name"] not in volumes:
                    volumes[volume["volume_name"]] = docker.Volume(volume["volume_name"])
            except Exception as e:
                pulumi.log.error(f"Failed to create volume {volume.get('volume_name')}: {e}")
        volumes_config = []
        try:
            if "volumes" in container:
                volumes_config = [
                    docker.ContainerVolumeArgs(
                        container_path=volume["container_path"],
                        volume_name=volumes[volume["volume_name"]].name
                    ) if "volume_name" in volume else
                    docker.ContainerVolumeArgs(
                        container_path=volume["container_path"],
                        host_path=os.path.abspath(volume["host_path"])
                    )
                    for volume in container["volumes"]
                ]
        except KeyError as e:
            pulumi.log.warn(f"Missing key in volume configuration: {e}")
        except Exception as e:
            pulumi.log.error(f"Error configuring volumes for container {container_name}: {e}")

        # Create the container
        try:
            container_resource = docker.Container(
                container_name,
                image=container["image"],
                hostname=container_name,
                envs=[
                    f"{key}={value}" for key, value in container.get("envs", {}).items()
                ] if "envs" in container else [],
                ports=[
                    docker.ContainerPortArgs(
                        internal=port["internal"],
                        external=port["external"] + i
                    ) for port in container.get("ports", [])
                ] if "ports" in container else [],
                volumes=volumes_config,
                network_mode=network.name if network else None,
            )
            ports = container.get("ports", [])
            if ports:
                for port in ports:
                    external_port = port["external"] + i
                    pulumi.export(
                        f"{container_name}_url",
                        f"http://localhost:{external_port}" 
                    )
        except Exception as e:
            pulumi.log.error(f"Failed to create container {container_name}: {e}")
>>>>>>> 3105cc3 (grafana)
